Rename state apogee -> coast
authorKeith Packard <keithp@keithp.com>
Sun, 14 Jun 2009 23:45:19 +0000 (16:45 -0700)
committerKeith Packard <keithp@keithp.com>
Sun, 14 Jun 2009 23:45:19 +0000 (16:45 -0700)
src/ao.h
src/ao_flight.c
src/ao_flight_test.c
src/ao_report.c
src/ao_state.c

index 20431b98d28080d6a848e3fd789d7cf9c86d05c6..02e10ec0fdad31b1f4ec3a02c799718af72af7f0 100644 (file)
--- a/src/ao.h
+++ b/src/ao.h
@@ -556,7 +556,7 @@ enum ao_flight_state {
        ao_flight_pad = 2,
        ao_flight_boost = 3,
        ao_flight_fast = 4,
        ao_flight_pad = 2,
        ao_flight_boost = 3,
        ao_flight_fast = 4,
-       ao_flight_apogee = 5,
+       ao_flight_coast = 5,
        ao_flight_drogue = 6,
        ao_flight_main = 7,
        ao_flight_landed = 8,
        ao_flight_drogue = 6,
        ao_flight_main = 7,
        ao_flight_landed = 8,
index 6de6e7cc324620c0f6b82c3ae317d61d5f6ceb45..be9b3bb6f4cfdbf4e55a9681dac98bbec304b471 100644 (file)
@@ -325,13 +325,13 @@ ao_flight(void)
                                 * apogee detect
                                 */
                                ao_min_vel = abs(ao_flight_vel);
                                 * apogee detect
                                 */
                                ao_min_vel = abs(ao_flight_vel);
-                               ao_flight_state = ao_flight_apogee;
+                               ao_flight_state = ao_flight_coast;
                                ao_wakeup(DATA_TO_XDATA(&ao_flight_state));
                        }
                        break;
                                ao_wakeup(DATA_TO_XDATA(&ao_flight_state));
                        }
                        break;
-               case ao_flight_apogee:
+               case ao_flight_coast:
 
 
/* apogee detect to drogue deploy:
                         *
                         * accelerometer: abs(velocity) > min_velocity + 2m/s
                         *               OR
                         *
                         * accelerometer: abs(velocity) > min_velocity + 2m/s
                         *               OR
index fde38dc334b2ccbbdc43902eba076b27241937e4..1466b886cae1576d062dad778c6ac49cf03b9aea 100644 (file)
@@ -51,7 +51,7 @@ enum ao_flight_state {
        ao_flight_pad = 2,
        ao_flight_boost = 3,
        ao_flight_fast = 4,
        ao_flight_pad = 2,
        ao_flight_boost = 3,
        ao_flight_fast = 4,
-       ao_flight_apogee = 5,
+       ao_flight_coast = 5,
        ao_flight_drogue = 6,
        ao_flight_main = 7,
        ao_flight_landed = 8,
        ao_flight_drogue = 6,
        ao_flight_main = 7,
        ao_flight_landed = 8,
@@ -106,7 +106,7 @@ ao_sleep(void *wchan);
 
 const char const * const ao_state_names[] = {
        "startup", "idle", "pad", "boost", "fast",
 
 const char const * const ao_state_names[] = {
        "startup", "idle", "pad", "boost", "fast",
-       "apogee", "drogue", "main", "landed", "invalid"
+       "coast", "drogue", "main", "landed", "invalid"
 };
 
 struct ao_cmds {
 };
 
 struct ao_cmds {
index 8885ea4e8b13f8196a7132247e6e47ec3c9b2cac..14eaf428e94a9f152d9c3dfdd631eae540715844 100644 (file)
@@ -23,7 +23,7 @@ static const char * __xdata flight_reports[] = {
        ".--.",         /* pad 'P' */
        "-...",         /* boost 'B' */
        "..-.",         /* fast 'F' */
        ".--.",         /* pad 'P' */
        "-...",         /* boost 'B' */
        "..-.",         /* fast 'F' */
-       ".-",           /* apogee 'A' */
+       "-.-.",         /* coast 'C' */
        "-..",          /* drogue 'D' */
        "--",           /* main 'M' */
        ".-..",         /* landed 'L' */
        "-..",          /* drogue 'D' */
        "--",           /* main 'M' */
        ".-..",         /* landed 'L' */
index c34435037cc4fef9b533268c3659216037e6f18e..ed197aa52ff9aa3c41e1f001d70273ae9f7185da 100644 (file)
@@ -19,5 +19,5 @@
 
 const char const * const ao_state_names[] = {
        "startup", "idle", "pad", "boost", "fast",
 
 const char const * const ao_state_names[] = {
        "startup", "idle", "pad", "boost", "fast",
-       "apogee", "drogue", "main", "landed", "invalid"
+       "coast", "drogue", "main", "landed", "invalid"
 };
 };
@@ -325,13 +325,13 @@ ao_flight(void)
 
 
-                       /* apogee detect to drogue deploy:
+                       /* apogee detect: coast to drogue deploy:
                         *
                         * accelerometer: abs(velocity) > min_velocity + 2m/s